@@ -7,7 +7,7 @@ import os
 import sys
 import tempfile
 
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 DEFAULTS = dict(
     path='/var/chef',
@@ -16,6 +16,7 @@ DEFAULTS = dict(
     gems='1.8.10',
     recipes=[],
     json={},
+    use_omnibus_installer = False,
 )
 
 SOLO_RB = """
@@ -70,6 +71,20 @@ def gems():
     if not files.exists('/usr/local/bin/chef-solo'):
         sudo('gem install chef --no-rdoc --no-ri -n /usr/local/bin')
 
+def omnibus_install():
+    """
+    Install Chef from Opscode's Omnibus installer
+    """
+    ctx = {
+        'filename':'%(path)s/install.sh' % chef,
+        'url':'http://opscode.com/chef/install.sh',
+    }
+    if not files.exists(ctx['filename']):
+        sudo('wget -O %(filename)s %(url)s' % ctx)
+    if not files.exists("/opt/opscode/bin/chef-solo"):
+        with cd(chef.path):
+            sudo('bash install.sh')
+
 def upload():
     ctx = {
         'cookbooks': '%(path)s/cookbooks' % chef,
@@ -107,13 +122,13 @@ def upload():
     files.append(ctx['solo.rb'], SOLO_RB % chef, use_sudo=True)
 
 @task(default=True)
-def provision():
+def provision(omnibus=False):
     sudo('mkdir -p %(path)s' % chef)
     apt()
-    gems()
+    if omnibus or chef.use_omnibus_installer:
+        omnibus_install()
+    else:
+        gems()
     upload()
     with cd(chef.path):
         sudo('chef-solo -c solo.rb -j node.json')
-    
-    
-    
